Class: Google::Apis::DataportabilityV1::InitiatePortabilityArchiveRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataportability_v1/classes.rb,
lib/google/apis/dataportability_v1/representations.rb,
lib/google/apis/dataportability_v1/representations.rb

Overview

Request to kick off an Archive job.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InitiatePortabilityArchiveRequest

Returns a new instance of InitiatePortabilityArchiveRequest.



134
135
136
# File 'lib/google/apis/dataportability_v1/classes.rb', line 134

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#end_timeString

Optional. The timestamp that represents the end point for the data you are exporting. If the end_time is not specified in the InitiatePortabilityArchiveRequest, this field is set to the latest available data. Corresponds to the JSON property endTime

Returns:

  • (String)


118
119
120
# File 'lib/google/apis/dataportability_v1/classes.rb', line 118

def end_time
  @end_time
end

#resourcesArray<String>

The resources from which you're exporting data. These values have a 1:1 correspondence with the OAuth scopes. Corresponds to the JSON property resources

Returns:

  • (Array<String>)


124
125
126
# File 'lib/google/apis/dataportability_v1/classes.rb', line 124

def resources
  @resources
end

#start_timeString

Optional. The timestamp that represents the starting point for the data you are exporting. If the start_time is not specified in the InitiatePortabilityArchiveRequest, the field is set to the earliest available data. Corresponds to the JSON property startTime

Returns:

  • (String)


132
133
134
# File 'lib/google/apis/dataportability_v1/classes.rb', line 132

def start_time
  @start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



139
140
141
142
143
# File 'lib/google/apis/dataportability_v1/classes.rb', line 139

def update!(**args)
  @end_time = args[:end_time] if args.key?(:end_time)
  @resources = args[:resources] if args.key?(:resources)
  @start_time = args[:start_time] if args.key?(:start_time)
end