Class: Google::Apis::DataportabilityV1::PortabilityArchiveState

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataportability_v1/classes.rb,
lib/google/apis/dataportability_v1/representations.rb,
lib/google/apis/dataportability_v1/representations.rb

Overview

Resource that contains the state of an Archive job.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PortabilityArchiveState

Returns a new instance of PortabilityArchiveState.



209
210
211
# File 'lib/google/apis/dataportability_v1/classes.rb', line 209

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#export_timeString

The timestamp that represents the end point for the data you are exporting. If the end_time value is set in the InitiatePortabilityArchiveRequest, this field is set to that value. If end_time is not set, this value is set to the time the export was requested. Corresponds to the JSON property exportTime

Returns:

  • (String)


182
183
184
# File 'lib/google/apis/dataportability_v1/classes.rb', line 182

def export_time
  @export_time
end

#nameString

The resource name of ArchiveJob's PortabilityArchiveState singleton. The format is: archiveJobs/archive_job/portabilityArchiveState. archive_job is the job ID provided in the request. Corresponds to the JSON property name

Returns:

  • (String)


189
190
191
# File 'lib/google/apis/dataportability_v1/classes.rb', line 189

def name
  @name
end

#start_timeString

The timestamp that represents the starting point for the data you are exporting. This field is set only if the start_time field is specified in the InitiatePortabilityArchiveRequest. Corresponds to the JSON property startTime

Returns:

  • (String)


196
197
198
# File 'lib/google/apis/dataportability_v1/classes.rb', line 196

def start_time
  @start_time
end

#stateString

Resource that represents the state of the Archive job. Corresponds to the JSON property state

Returns:

  • (String)


201
202
203
# File 'lib/google/apis/dataportability_v1/classes.rb', line 201

def state
  @state
end

#urlsArray<String>

If the state is complete, this method returns the signed URLs of the objects in the Cloud Storage bucket. Corresponds to the JSON property urls

Returns:

  • (Array<String>)


207
208
209
# File 'lib/google/apis/dataportability_v1/classes.rb', line 207

def urls
  @urls
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



214
215
216
217
218
219
220
# File 'lib/google/apis/dataportability_v1/classes.rb', line 214

def update!(**args)
  @export_time = args[:export_time] if args.key?(:export_time)
  @name = args[:name] if args.key?(:name)
  @start_time = args[:start_time] if args.key?(:start_time)
  @state = args[:state] if args.key?(:state)
  @urls = args[:urls] if args.key?(:urls)
end