Module: Google::Apis::DataportabilityV1
- Defined in:
- lib/google/apis/dataportability_v1.rb,
lib/google/apis/dataportability_v1/classes.rb,
lib/google/apis/dataportability_v1/service.rb,
lib/google/apis/dataportability_v1/gem_version.rb,
lib/google/apis/dataportability_v1/representations.rb
Overview
Data Portability API
The Data Portability API lets you build applications that request authorization from a user to move a copy of data from Google services into your application. This enables data portability and facilitates switching services.
Defined Under Namespace
Classes: CancelPortabilityArchiveRequest, CancelPortabilityArchiveResponse, CheckAccessTypeRequest, CheckAccessTypeResponse, DataPortabilityService, Empty, InitiatePortabilityArchiveRequest, InitiatePortabilityArchiveResponse, PortabilityArchiveState, ResetAuthorizationRequest, RetryPortabilityArchiveRequest, RetryPortabilityArchiveResponse
Constant Summary collapse
- GEM_VERSION =
Version of the google-apis-dataportability_v1 gem
"0.14.0"- GENERATOR_VERSION =
Version of the code generator used to generate this client
"0.19.0"- REVISION =
Revision of the discovery document this client was generated from
"20260105"- VERSION =
Version of the Data Portability API this client connects to. This is NOT the gem version.
'V1'- AUTH_DATAPORTABILITY_ALERTS_SUBSCRIPTIONS =
Move a copy of the Google Alerts subscriptions you created
'https://www.googleapis.com/auth/dataportability.alerts.subscriptions'- AUTH_DATAPORTABILITY_CHROME_AUTOFILL =
Move a copy of the information you entered into online forms in Chrome
'https://www.googleapis.com/auth/dataportability.chrome.autofill'- AUTH_DATAPORTABILITY_CHROME_BOOKMARKS =
Move a copy of pages you bookmarked in Chrome
'https://www.googleapis.com/auth/dataportability.chrome.bookmarks'- AUTH_DATAPORTABILITY_CHROME_DICTIONARY =
Move a copy of words you added to Chrome's dictionary
'https://www.googleapis.com/auth/dataportability.chrome.dictionary'- AUTH_DATAPORTABILITY_CHROME_EXTENSIONS =
Move a copy of extensions you installed from the Chrome Web Store
'https://www.googleapis.com/auth/dataportability.chrome.extensions'- AUTH_DATAPORTABILITY_CHROME_HISTORY =
Move a copy of sites you visited in Chrome
'https://www.googleapis.com/auth/dataportability.chrome.history'- AUTH_DATAPORTABILITY_CHROME_READING_LIST =
Move a copy of pages you added to your reading list in Chrome
'https://www.googleapis.com/auth/dataportability.chrome.reading_list'- AUTH_DATAPORTABILITY_CHROME_SETTINGS =
Move a copy of your settings in Chrome
'https://www.googleapis.com/auth/dataportability.chrome.settings'- AUTH_DATAPORTABILITY_DISCOVER_FOLLOWS =
Move a copy of searches and sites you follow, saved by Discover
'https://www.googleapis.com/auth/dataportability.discover.follows'- AUTH_DATAPORTABILITY_DISCOVER_LIKES =
Move a copy of links to your liked documents, saved by Discover
'https://www.googleapis.com/auth/dataportability.discover.likes'- AUTH_DATAPORTABILITY_DISCOVER_NOT_INTERESTED =
Move a copy of content you marked as not interested, saved by Discover
'https://www.googleapis.com/auth/dataportability.discover.not_interested'- AUTH_DATAPORTABILITY_MAPS_ALIASED_PLACES =
Move a copy of the places you labeled on Maps
'https://www.googleapis.com/auth/dataportability.maps.aliased_places'- AUTH_DATAPORTABILITY_MAPS_COMMUTE_ROUTES =
Move a copy of your pinned trips on Maps
'https://www.googleapis.com/auth/dataportability.maps.commute_routes'- AUTH_DATAPORTABILITY_MAPS_COMMUTE_SETTINGS =
Move a copy of your commute settings on Maps
'https://www.googleapis.com/auth/dataportability.maps.commute_settings'- AUTH_DATAPORTABILITY_MAPS_EV_PROFILE =
Move a copy of your electric vehicle profile on Maps
'https://www.googleapis.com/auth/dataportability.maps.ev_profile'- AUTH_DATAPORTABILITY_MAPS_FACTUAL_CONTRIBUTIONS =
Move a copy of the corrections you made to places or map information on Maps
'https://www.googleapis.com/auth/dataportability.maps.factual_contributions'- AUTH_DATAPORTABILITY_MAPS_OFFERING_CONTRIBUTIONS =
Move a copy of your updates to places on Maps
'https://www.googleapis.com/auth/dataportability.maps.offering_contributions'- AUTH_DATAPORTABILITY_MAPS_PHOTOS_VIDEOS =
Move a copy of the photos and videos you posted on Maps
'https://www.googleapis.com/auth/dataportability.maps.photos_videos'- AUTH_DATAPORTABILITY_MAPS_QUESTIONS_ANSWERS =
Move a copy of the questions and answers you posted on Maps
'https://www.googleapis.com/auth/dataportability.maps.questions_answers'- AUTH_DATAPORTABILITY_MAPS_REVIEWS =
Move a copy of your reviews and posts on Maps
'https://www.googleapis.com/auth/dataportability.maps.reviews'- AUTH_DATAPORTABILITY_MAPS_STARRED_PLACES =
Move a copy of your Starred places list on Maps
'https://www.googleapis.com/auth/dataportability.maps.starred_places'- AUTH_DATAPORTABILITY_MAPS_VEHICLE_PROFILE =
Move a copy of your vehicle profile on Maps
'https://www.googleapis.com/auth/dataportability.maps.vehicle_profile'- AUTH_DATAPORTABILITY_MYACTIVITY_MAPS =
Move a copy of your Maps activity
'https://www.googleapis.com/auth/dataportability.myactivity.maps'- AUTH_DATAPORTABILITY_MYACTIVITY_MYADCENTER =
Move a copy of your My Ad Center activity
'https://www.googleapis.com/auth/dataportability.myactivity.myadcenter'- AUTH_DATAPORTABILITY_MYACTIVITY_PLAY =
Move a copy of your Google Play activity
'https://www.googleapis.com/auth/dataportability.myactivity.play'- AUTH_DATAPORTABILITY_MYACTIVITY_SEARCH =
Move a copy of your Google Search activity
'https://www.googleapis.com/auth/dataportability.myactivity.search'- AUTH_DATAPORTABILITY_MYACTIVITY_SHOPPING =
Move a copy of your Shopping activity
'https://www.googleapis.com/auth/dataportability.myactivity.shopping'- AUTH_DATAPORTABILITY_MYACTIVITY_YOUTUBE =
Move a copy of your YouTube activity
'https://www.googleapis.com/auth/dataportability.myactivity.youtube'- AUTH_DATAPORTABILITY_MYMAPS_MAPS =
Move a copy of the maps you created in My Maps
'https://www.googleapis.com/auth/dataportability.mymaps.maps'- AUTH_DATAPORTABILITY_NEST_CAMERA_EVENT =
Copy Nest camera event data
'https://www.googleapis.com/auth/dataportability.nest.camera_event'- AUTH_DATAPORTABILITY_NEST_CAMERA_FEATURE =
Copy Nest camera feature data
'https://www.googleapis.com/auth/dataportability.nest.camera_feature'- AUTH_DATAPORTABILITY_NEST_CAMERA_VIDEO =
Copy Nest camera footage
'https://www.googleapis.com/auth/dataportability.nest.camera_video'- AUTH_DATAPORTABILITY_NEST_STORE =
Copy your Nest Store and Nest Renew billing and payment information
'https://www.googleapis.com/auth/dataportability.nest.store'- AUTH_DATAPORTABILITY_NEST_USER =
Copy your Nest user information
'https://www.googleapis.com/auth/dataportability.nest.user'- AUTH_DATAPORTABILITY_ORDER_RESERVE_PURCHASES_RESERVATIONS =
Move a copy of your food purchase and reservation activity
'https://www.googleapis.com/auth/dataportability.order_reserve.purchases_reservations'- AUTH_DATAPORTABILITY_PLAY_DEVICES =
Move a copy of information about your devices with Google Play Store installed
'https://www.googleapis.com/auth/dataportability.play.devices'- AUTH_DATAPORTABILITY_PLAY_GROUPING =
Move a copy of your Google Play Store Grouping tags created by app developers
'https://www.googleapis.com/auth/dataportability.play.grouping'- AUTH_DATAPORTABILITY_PLAY_INSTALLS =
Move a copy of your Google Play Store app installations
'https://www.googleapis.com/auth/dataportability.play.installs'- AUTH_DATAPORTABILITY_PLAY_LIBRARY =
Move a copy of your Google Play Store downloads, including books, games, and apps
'https://www.googleapis.com/auth/dataportability.play.library'- AUTH_DATAPORTABILITY_PLAY_PLAYPOINTS =
Move a copy of information about your Google Play Store Points
'https://www.googleapis.com/auth/dataportability.play.playpoints'- AUTH_DATAPORTABILITY_PLAY_PROMOTIONS =
Move a copy of information about your Google Play Store promotions
'https://www.googleapis.com/auth/dataportability.play.promotions'- AUTH_DATAPORTABILITY_PLAY_PURCHASES =
Move a copy of your Google Play Store purchases
'https://www.googleapis.com/auth/dataportability.play.purchases'- AUTH_DATAPORTABILITY_PLAY_REDEMPTIONS =
Move a copy of your Google Play Store redemption activities
'https://www.googleapis.com/auth/dataportability.play.redemptions'- AUTH_DATAPORTABILITY_PLAY_SUBSCRIPTIONS =
Move a copy of your Google Play Store subscriptions
'https://www.googleapis.com/auth/dataportability.play.subscriptions'- AUTH_DATAPORTABILITY_PLAY_USERSETTINGS =
Move a copy of your Google Play Store user settings and preferences
'https://www.googleapis.com/auth/dataportability.play.usersettings'- AUTH_DATAPORTABILITY_SAVED_COLLECTIONS =
Move a copy of your saved links, images, places, and collections from your use of Google services
'https://www.googleapis.com/auth/dataportability.saved.collections'- AUTH_DATAPORTABILITY_SEARCH_UGC_COMMENTS =
Move a copy of your comments on Google Search
'https://www.googleapis.com/auth/dataportability.search_ugc.comments'- AUTH_DATAPORTABILITY_SEARCH_UGC_MEDIA_REVIEWS_AND_STARS =
Move a copy of your media reviews on Google Search
'https://www.googleapis.com/auth/dataportability.search_ugc.media.reviews_and_stars'- AUTH_DATAPORTABILITY_SEARCH_UGC_MEDIA_STREAMING_VIDEO_PROVIDERS =
Move a copy of your self-reported video streaming provider preferences from Google Search and Google TV
'https://www.googleapis.com/auth/dataportability.search_ugc.media.streaming_video_providers'- AUTH_DATAPORTABILITY_SEARCH_UGC_MEDIA_THUMBS =
Move a copy of your indicated thumbs up and thumbs down on media in Google Search and Google TV
'https://www.googleapis.com/auth/dataportability.search_ugc.media.thumbs'- AUTH_DATAPORTABILITY_SEARCH_UGC_MEDIA_WATCHED =
Move a copy of information about the movies and TV shows you marked as watched on Google Search and Google TV
'https://www.googleapis.com/auth/dataportability.search_ugc.media.watched'- AUTH_DATAPORTABILITY_SEARCHNOTIFICATIONS_SETTINGS =
Move a copy of your notification settings on the Google Search app
'https://www.googleapis.com/auth/dataportability.searchnotifications.settings'- AUTH_DATAPORTABILITY_SEARCHNOTIFICATIONS_SUBSCRIPTIONS =
Move a copy of your notification subscriptions on Google Search app
'https://www.googleapis.com/auth/dataportability.searchnotifications.subscriptions'- AUTH_DATAPORTABILITY_SHOPPING_ADDRESSES =
Move a copy of your shipping information on Shopping
'https://www.googleapis.com/auth/dataportability.shopping.addresses'- AUTH_DATAPORTABILITY_SHOPPING_REVIEWS =
Move a copy of reviews you wrote about products or online stores on Google Search
'https://www.googleapis.com/auth/dataportability.shopping.reviews'- AUTH_DATAPORTABILITY_STREETVIEW_IMAGERY =
Move a copy of the images and videos you uploaded to Street View
'https://www.googleapis.com/auth/dataportability.streetview.imagery'- AUTH_DATAPORTABILITY_YOUTUBE_CHANNEL =
Move a copy of information about your YouTube channel
'https://www.googleapis.com/auth/dataportability.youtube.channel'- AUTH_DATAPORTABILITY_YOUTUBE_CLIPS =
Move a copy of your YouTube clips metadata
'https://www.googleapis.com/auth/dataportability.youtube.clips'- AUTH_DATAPORTABILITY_YOUTUBE_COMMENTS =
Move a copy of your YouTube comments
'https://www.googleapis.com/auth/dataportability.youtube.comments'- AUTH_DATAPORTABILITY_YOUTUBE_CONVERSATIONS =
Move a copy of all your YouTube messages
'https://www.googleapis.com/auth/dataportability.youtube.conversations'- AUTH_DATAPORTABILITY_YOUTUBE_LIVE_CHAT =
Move a copy of your YouTube messages in live chat
'https://www.googleapis.com/auth/dataportability.youtube.live_chat'- AUTH_DATAPORTABILITY_YOUTUBE_MUSIC =
Move a copy of your uploaded YouTube music tracks and your YouTube music library
'https://www.googleapis.com/auth/dataportability.youtube.music'- AUTH_DATAPORTABILITY_YOUTUBE_PLAYABLE =
Move a copy of your YouTube playables saved game progress files
'https://www.googleapis.com/auth/dataportability.youtube.playable'- AUTH_DATAPORTABILITY_YOUTUBE_POSTS =
Move a copy of your YouTube posts
'https://www.googleapis.com/auth/dataportability.youtube.posts'- AUTH_DATAPORTABILITY_YOUTUBE_PRIVATE_PLAYLISTS =
Move a copy of your YouTube private playlists
'https://www.googleapis.com/auth/dataportability.youtube.private_playlists'- AUTH_DATAPORTABILITY_YOUTUBE_PRIVATE_VIDEOS =
Move a copy of your private YouTube videos and information about them
'https://www.googleapis.com/auth/dataportability.youtube.private_videos'- AUTH_DATAPORTABILITY_YOUTUBE_PUBLIC_PLAYLISTS =
Move a copy of your public YouTube playlists
'https://www.googleapis.com/auth/dataportability.youtube.public_playlists'- AUTH_DATAPORTABILITY_YOUTUBE_PUBLIC_VIDEOS =
Move a copy of your public YouTube videos and information about them
'https://www.googleapis.com/auth/dataportability.youtube.public_videos'- AUTH_DATAPORTABILITY_YOUTUBE_SHOPPING =
Move a copy of your YouTube shopping wishlists, and wishlist items
'https://www.googleapis.com/auth/dataportability.youtube.shopping'- AUTH_DATAPORTABILITY_YOUTUBE_SUBSCRIPTIONS =
Move a copy of your YouTube channel subscriptions, even if they're private
'https://www.googleapis.com/auth/dataportability.youtube.subscriptions'- AUTH_DATAPORTABILITY_YOUTUBE_UNLISTED_PLAYLISTS =
Move a copy of your unlisted YouTube playlists
'https://www.googleapis.com/auth/dataportability.youtube.unlisted_playlists'- AUTH_DATAPORTABILITY_YOUTUBE_UNLISTED_VIDEOS =
Move a copy of your unlisted YouTube videos and information about them
'https://www.googleapis.com/auth/dataportability.youtube.unlisted_videos'