Class: Google::Apis::DataportabilityV1::InitiatePortabilityArchiveResponse
- Inherits:
-
Object
- Object
- Google::Apis::DataportabilityV1::InitiatePortabilityArchiveResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataportability_v1/classes.rb,
lib/google/apis/dataportability_v1/representations.rb,
lib/google/apis/dataportability_v1/representations.rb
Overview
Response from initiating an Archive job.
Instance Attribute Summary collapse
-
#access_type ⇒ String
The access type of the Archive job initiated by the API.
-
#archive_job_id ⇒ String
The archive job ID that is initiated in the API.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InitiatePortabilityArchiveResponse
constructor
A new instance of InitiatePortabilityArchiveResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InitiatePortabilityArchiveResponse
Returns a new instance of InitiatePortabilityArchiveResponse.
161 162 163 |
# File 'lib/google/apis/dataportability_v1/classes.rb', line 161 def initialize(**args) update!(**args) end |
Instance Attribute Details
#access_type ⇒ String
The access type of the Archive job initiated by the API.
Corresponds to the JSON property accessType
153 154 155 |
# File 'lib/google/apis/dataportability_v1/classes.rb', line 153 def access_type @access_type end |
#archive_job_id ⇒ String
The archive job ID that is initiated in the API. This can be used to get the
state of the job.
Corresponds to the JSON property archiveJobId
159 160 161 |
# File 'lib/google/apis/dataportability_v1/classes.rb', line 159 def archive_job_id @archive_job_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
166 167 168 169 |
# File 'lib/google/apis/dataportability_v1/classes.rb', line 166 def update!(**args) @access_type = args[:access_type] if args.key?(:access_type) @archive_job_id = args[:archive_job_id] if args.key?(:archive_job_id) end |